[llvm-commits] CVS: llvm/lib/Target/X86/InstSelectSimple.cpp X86.h X86TargetMachine.cpp

Chris Lattner lattner at cs.uiuc.edu
Sat Jul 26 18:51:00 PDT 2003


Changes in directory llvm/lib/Target/X86:

InstSelectSimple.cpp updated: 1.116 -> 1.117
X86.h updated: 1.14 -> 1.15
X86TargetMachine.cpp updated: 1.19 -> 1.20

---
Log message:

Rename function to be more consistent with filename


---
Diffs of the changes:

Index: llvm/lib/Target/X86/X86TargetMachine.cpp
diff -u llvm/lib/Target/X86/X86TargetMachine.cpp:1.19 llvm/lib/Target/X86/X86TargetMachine.cpp:1.20
--- llvm/lib/Target/X86/X86TargetMachine.cpp:1.19	Wed Jul 23 15:25:08 2003
+++ llvm/lib/Target/X86/X86TargetMachine.cpp	Sat Jul 26 18:49:58 2003
@@ -45,7 +45,7 @@
 bool X86TargetMachine::addPassesToEmitAssembly(PassManager &PM,
 					       std::ostream &Out) {
   PM.add(createLowerSwitchPass());
-  PM.add(createSimpleX86InstructionSelector(*this));
+  PM.add(createX86SimpleInstructionSelector(*this));
   PM.add(createLocalRegisterAllocator());
   PM.add(createX86FloatingPointStackifierPass());
   PM.add(createPrologEpilogCodeInserter());
@@ -62,7 +62,7 @@
   // FIXME: Implement the switch instruction in the instruction selector!
   PM.add(createLowerSwitchPass());
 
-  PM.add(createSimpleX86InstructionSelector(*this));
+  PM.add(createX86SimpleInstructionSelector(*this));
 
   // TODO: optional optimizations go here
 





More information about the llvm-commits mailing list
Index: llvm/lib/Target/X86/InstSelectSimple.cpp
diff -u llvm/lib/Target/X86/InstSelectSimple.cpp:1.116 llvm/lib/Target/X86/InstSelectSimple.cpp:1.117
--- llvm/lib/Target/X86/InstSelectSimple.cpp:1.116	Sat Jul 26 18:05:37 2003
+++ llvm/lib/Target/X86/InstSelectSimple.cpp	Sat Jul 26 18:49:58 2003
@@ -2091,10 +2091,10 @@
 }
    
 
 /// createSimpleX86InstructionSelector - This pass converts an LLVM function
 /// into a machine code representation is a very simple peep-hole fashion.  The
 /// generated code sucks but the implementation is nice and simple.
 ///
-Pass *createSimpleX86InstructionSelector(TargetMachine &TM) {
+Pass *createX86SimpleInstructionSelector(TargetMachine &TM) {
   return new ISel(TM);
 }
@@ -2091,10 +2091,10 @@
    
 
-/// createSimpleX86InstructionSelector - This pass converts an LLVM function
+/// createX86SimpleInstructionSelector - This pass converts an LLVM function
 /// into a machine code representation is a very simple peep-hole fashion.  The
 /// generated code sucks but the implementation is nice and simple.


Index: llvm/lib/Target/X86/X86.h
diff -u llvm/lib/Target/X86/X86.h:1.14 llvm/lib/Target/X86/X86.h:1.15
--- llvm/lib/Target/X86/X86.h:1.14	Wed Jul 23 15:25:08 2003
+++ llvm/lib/Target/X86/X86.h	Sat Jul 26 18:49:58 2003
@@ -12,11 +12,11 @@
 class TargetMachine;
 class Pass;
 
 /// createSimpleX86InstructionSelector - This pass converts an LLVM function
 /// into a machine code representation is a very simple peep-hole fashion.  The
 /// generated code sucks but the implementation is nice and simple.
 ///
-Pass *createSimpleX86InstructionSelector(TargetMachine &TM);
+Pass *createX86SimpleInstructionSelector(TargetMachine &TM);
 
 /// createX86PeepholeOptimizer - Create a pass to perform X86 specific peephole
 /// optimizations.
@@ -12,11 +12,11 @@
 class Pass;
 
-/// createSimpleX86InstructionSelector - This pass converts an LLVM function
+/// createX86SimpleInstructionSelector - This pass converts an LLVM function
 /// into a machine code representation is a very simple peep-hole fashion.  The
 /// generated code sucks but the implementation is nice and simple.

